define((function () { 'use strict';

function foo () {
	console.log( 'not indented' );
}

return foo;

}));
